package com.example.chatgptapi.controller;

import org.springframework.http.*;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.client.RestTemplate;

import java.util.ArrayList;
import java.util.List;

@Controller
public class ChatController {

    private final List<String> chatMessages = new ArrayList<>();

    @GetMapping("/")
    public String chat(Model model) {
        model.addAttribute("messages", chatMessages);
        return "chat";
    }

    @PostMapping("/sendMessage")
    public String sendMessage(@RequestParam String userMessage) {
        chatMessages.add("User: " + userMessage);

        // Call ChatGPT API to generate a response
        String chatGptResponse = generateChatGptResponse(userMessage);

        if (chatGptResponse != null) {
            chatMessages.add("ChatGPT: " + chatGptResponse);
        }

        return "redirect:/";
    }

    private String generateChatGptResponse(String userMessage) {
        HttpHeaders headers = new HttpHeaders();
        String chatGptApiKey = "YOUR_CHATGPT_API_KEY ";
        headers.setBearerAuth(chatGptApiKey);
        headers.setContentType(MediaType.APPLICATION_JSON);

        String requestBody = "{\"prompt\": \"" + userMessage + "\", \"max_tokens\": 50}";

        HttpEntity<String> requestEntity = new HttpEntity<>(requestBody, headers);

        RestTemplate restTemplate = new RestTemplate();
        // Replace with your ChatGPT API URL
        String chatGptApiUrl = "https://api.openai.com/v1/engines/davinci-codex/completions";
        ResponseEntity<String> responseEntity = restTemplate.exchange(
                chatGptApiUrl,
                HttpMethod.POST,
                requestEntity,
                String.class
        );

        if (responseEntity.getStatusCode() == HttpStatus.OK) {
            return responseEntity.getBody();
        } else {
            // Handle API call error here
            return "Error communicating with ChatGPT API.";
        }
    }
}
